@@ -6,8 +6,7 @@ from .ssoup import getSoup, getPostId
 from .model import Post, getPostFromSoup
 
 def _yieldPosts(name, soup):
-	post = getPostFromSoup(name, soup)
-	yield post
+	yield getPostFromSoup(name, soup)
 	for sub_soup in soup.find_all('div', class_='tgme_widget_message_bubble'):
 		post = getPostFromSoup(name, sub_soup)
 		try:
@@ -17,15 +16,18 @@ def _yieldPosts(name, soup):
 		except:
 			...
 
-def _getPostsSoup(name, post_id, direction):
+def _getPostsSoup(name, post_id, direction, ttl):
 	link = 'https://t.me/s/' + name
 	if post_id:
 		link += '?%s=%d' % (direction, post_id)
-	return getSoup(link, force_cache=post_id)
+		ttl = float('Inf')
+	return getSoup(link, ttl=ttl)
 
-def getPosts(name, post_id=None, direction='after'):
-	soup = _getPostsSoup(name, post_id = post_id, 
-		direction = direction)
+# force_cache flag is deprecated
+def getPosts(name, post_id=None, direction='after', force_cache = False, ttl = 1):
+	if force_cache:
+		ttl = float('Inf')
+	soup = _getPostsSoup(name, post_id, direction, ttl)
 	return list(_yieldPosts(name, soup))
 
 def getPost(name, post_id):
